@@ -14,15 +14,15 @@ logging.basicConfig(format="%(message)s", level=logging.INFO)
 log = lambda message: logging.info(message)
 
 
-VERSION = "2022-09-28"
+VERSION = "2022-10-01"
 HELP = f"""
 trim reads from single or paired fastq files
-expect all sequences (reads and given adapters) to be 5' -> 3' oriented
-adapters from paired-end reads are only trimmed if present at same place in both reads
-reads or read pairs order may not be preserved if --parallel > 1 or --deduplicate set
+expect all sequences (reads and adapters) to be 5' -> 3' oriented
+paired-end reads are only trimmed if adapter present at same place in both reads
+reads or pairs order may not be preserved if --parallel > 1 or --deduplicate set
 
 arguments:
-  -i --inputs       input fastq paths (single or r1 and r2)
+  -i --inputs       input fastq paths (single or r1 and r2, may be gzipped)
                     required
   -o --outputs      output fastq paths (matching inputs)
                     will be gzipped if path ends with .gz
@@ -212,7 +212,7 @@ def sync_process(sync_queue_in, sync_queue_out, read_process_count):
         if all(dones):
             if any(size != min_common_size for size in sizes):
                 counts = "\n".join(sorted(
-                    f"    {path}: {total_send_size + size:,} reads"
+                    f"    {path}: {(total_send_size + size) // 4:,} reads"
                     for path, size in zip(paths, sizes)))
                 raise RuntimeError(f"input files corrupted: read count mismatch between files:\n{counts}")
             keep_going = False
@@ -338,8 +338,7 @@ class Controller:
                 args=[queue, *task[2]],
                 daemon=self.daemon)
             process.start()
-            task[2] = None
-            task[3] = process
+            task[2], task[3] = None, process
         self.thread = threading.Thread(
             target=self.run_thread,
             args=[queue],
